@@ -3,7 +3,7 @@
 
 from typing import Dict, Sequence
 
-from gpt_index.indices.data_structs import IndexGraph, Node
+from gpt_index.data_structs import IndexGraph, Node
 from gpt_index.indices.prompt_helper import PromptHelper
 from gpt_index.indices.utils import get_sorted_node_list, truncate_text
 from gpt_index.langchain_helpers.chain_wrapper import LLMPredictor
@@ -33,15 +33,16 @@ class GPTTreeIndexBuilder:
         self.summary_prompt = summary_prompt
         self._llm_predictor = llm_predictor
         self._prompt_helper = prompt_helper
-        self._text_splitter = self._prompt_helper.get_text_splitter_given_prompt(
-            self.summary_prompt, self.num_children
-        )
 
     def _get_nodes_from_document(
         self, start_idx: int, document: BaseDocument
     ) -> Dict[int, Node]:
         """Add document to index."""
-        text_chunks = self._text_splitter.split_text(document.get_text())
+        # NOTE: summary prompt does not need to be partially formatted
+        text_splitter = self._prompt_helper.get_text_splitter_given_prompt(
+            self.summary_prompt, self.num_children
+        )
+        text_chunks = text_splitter.split_text(document.get_text())
         doc_nodes = {
             (start_idx + i): Node(
                 text=t, index=(start_idx + i), ref_doc_id=document.get_doc_id()
