@@ -7,8 +7,8 @@ in sequence in order to answer a given query.
 
 from typing import Any, Optional, Sequence
 
+from gpt_index.data_structs import IndexList
 from gpt_index.indices.base import DOCUMENTS_INPUT, BaseGPTIndex
-from gpt_index.indices.data_structs import IndexList
 from gpt_index.indices.utils import truncate_text
 from gpt_index.langchain_helpers.chain_wrapper import LLMPredictor
 from gpt_index.langchain_helpers.text_splitter import TokenTextSplitter
@@ -55,6 +55,8 @@ class GPTListIndex(BaseGPTIndex[IndexList]):
             llm_predictor=llm_predictor,
             **kwargs,
         )
+        # NOTE: when building the list index, text_qa_template is not partially
+        # formatted because we don't know the query ahead of time.
         self._text_splitter = self._prompt_helper.get_text_splitter_given_prompt(
             self.text_qa_template, 1
         )
