@@ -2,8 +2,9 @@
 
 from typing import Any, Dict, List, Optional, Tuple
 
+from gpt_index.data_structs import IndexGraph, Node
+from gpt_index.embeddings.base import BaseEmbedding
 from gpt_index.embeddings.openai import OpenAIEmbedding
-from gpt_index.indices.data_structs import IndexGraph, Node
 from gpt_index.indices.query.tree.leaf_query import GPTTreeIndexLeafQuery
 from gpt_index.indices.utils import get_sorted_node_list
 from gpt_index.prompts.prompts import (
@@ -39,7 +40,7 @@ class GPTTreeIndexEmbeddingQuery(GPTTreeIndexLeafQuery):
             If child_branch_factor is 1, then the query will only choose one child node
             to traverse for any given parent node.
             If child_branch_factor is 2, then the query will choose two child nodes.
-        embed_model (Optional[OpenAIEmbedding]): Embedding model to use for
+        embed_model (Optional[BaseEmbedding]): Embedding model to use for
             embedding similarity.
 
     """
@@ -52,7 +53,7 @@ class GPTTreeIndexEmbeddingQuery(GPTTreeIndexLeafQuery):
         text_qa_template: Optional[QuestionAnswerPrompt] = None,
         refine_template: Optional[RefinePrompt] = None,
         child_branch_factor: int = 1,
-        embed_model: Optional[OpenAIEmbedding] = None,
+        embed_model: Optional[BaseEmbedding] = None,
         **kwargs: Any,
     ) -> None:
         """Initialize params."""
