@@ -2,5 +2,6 @@
 
 from gpt_index.indices.vector_store.faiss import GPTFaissIndex
 from gpt_index.indices.vector_store.simple import GPTSimpleVectorIndex
+from gpt_index.indices.vector_store.weaviate import GPTWeaviateIndex
 
-__all__ = ["GPTFaissIndex", "GPTSimpleVectorIndex"]
+__all__ = ["GPTFaissIndex", "GPTSimpleVectorIndex", "GPTWeaviateIndex"]
