@@ -20,7 +20,7 @@ from gpt_index.readers.notion import NotionPageReader
 from gpt_index.readers.pinecone import PineconeReader
 from gpt_index.readers.schema.base import Document
 from gpt_index.readers.slack import SlackReader
-from gpt_index.readers.weaviate import WeaviateReader
+from gpt_index.readers.weaviate.reader import WeaviateReader
 from gpt_index.readers.wikipedia import WikipediaReader
 
 __all__ = [
